/*
* Generic
*/
body, div, ul, ol, li, a, section, nav,
h1, h2, h3, h4, h5, h6, label,
hr, input, textarea {
    -moz-box-sizing:border-box;
    -webkit-box-sizing:border-box;
    box-sizing: border-box;
    margin: 0;
    padding: 0;
    font-family: "fira_sans", -apple-system, BlinkMacSystemFont,
    "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell",
    "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
}
body, div, ul, ol, li, a, section, nav,
h1, h2, h3, h4, h5, h6, label, hr {
    padding: 0;
}
a {
    text-decoration: none;
    color: SeaGreen;
}
button {
    cursor: pointer;
}
hr {
    clear: both;
    width: 100%;
    height: 0;
    max-width: 980px;
    margin: 28px auto;
    -moz-border-bottom-colors: none;
    -moz-border-left-colors: none;
    -moz-border-right-colors: none;
    -moz-border-top-colors: none;
    border-color: var(--color-lightGray);
    border-image: none;
    border-style: solid;
    border-width: 1px 0 0;
}
h1, h2 {
    margin-bottom: 28px;
}
h3, h4, h5 {
    margin-bottom: 14px;
}
p {
    line-height: 21px;
    margin-top: 14px;
    margin-bottom: 14px;
}
kbd {
  border: 1px solid #b4b4b4;
  box-shadow:
    0 1px 1px rgba(0, 0, 0, 0.2),
    0 2px 0 0 rgba(255, 255, 255, 0.7) inset;
  border-radius: 3px;
  padding: 1px 4px;
  display: inline-block;
  white-space: nowrap;
}

/*
* List
*/
ul {
    list-style-image:none;
    list-style-position:inside;
    list-style-type:none;
}

/* ************************************************* */
/* *********************** GRID ******************** */
/* ************************************************* */
.wrapper {
    width: 100%;
    clear: both;
}
.wrapper:after {
    visibility: hidden;
    display: block;
    font-size: 0;
    content: " ";
    clear: both;
    height: 0;
}
.row {
    width: 100%;
    max-width: 1200px;
    clear: both;
    margin-left: auto;
    margin-right: auto;
    margin-top: 0;
    margin-bottom: 2rem;
}
.col {
    float: left;
}
.right {
    float: right;
}
.col + .col {
    padding-left: 20px;
}
.half {
    width: 50%;
}
.third {
    width: 33.33%;
}
.two-third {
    width: 66.66%
}
.quarter {
    width: 25%;
}
.wide {
    width: 100%;
}
.col + .wide {
    padding-left: inherit;
}
.mshow, .tshow {
    display: none;
}
.center {
    margin-left: auto;
    margin-right: auto;
    float: none;
}


/* *********** */
/*    forms    */
/* *********** */
input[type="text"], input[type="password"], input[type="date"],
input[type="datetime-local"], input[type="email"], input[type="number"],
input[type="search"], input[type="tel"], input[type="time"],
input[type="url"], textarea {
    background-color: white;
    border: 1px solid #CCCCCC;
    border-radius: 2px 2px 2px 2px;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset;
    color: rgba(0, 0, 0, 0.75);
    display: block;
    font-family: inherit;
    font-size: 14px;
    height: 32px;
    margin: 0 0 14px;
    padding: 7px;
    width: 100%;
}
input[type="range"] {
    margin-top: 10px;
    margin-bottom: 5px;
    width: 100%;
}
input[type="checkbox"] {
    margin: 0 5px;
    vertical-align: middle;
}
textarea {
    height: inherit;
    padding: 7px;
    min-height: 15rem;
    min-height: 6rlh;
}
select {
    border: 1px solid #222;
    width: 100%;
    height: 28px;
    line-height: 28px;
    margin-top: 5px;
}
.dark select {
    color: #efefef;
    background-color: #393F3F;
}
select[multiple="multiple"] {
    height: auto;
}
.button,
[type="button"],
input[type="submit"] {
    display: block;
    margin-bottom: 14px;
    text-align: center;
    border-radius: 2px;
    font-weight: normal;
    cursor: pointer;
    padding: 7px;
    width: 100%;
    min-height: 32px;
    line-height: 32px;
    border: none;
    text-decoration: none;
    background-color: white;
}
.dark .button,
.dark [type="button"] {
    background-color: #2a2e30;
    color: #eeeeec;
    border: 1px solid #1b1f20;
}
.dark .button:hover,
.dark [type="button"]:hover,
.dark input[type="submit"]:hover {
    background-color: #2e3436;
}
.dark a {
    color: #eeeeec;
}
button.flat,
[type="button"].flat,
.dark [type="button"].flat {
    border: none;
    background-color: inherit;
    padding: 0;
    text-align: left;
    min-height: inherit;
    width: initial;
    display: initial;
    text-decoration: underline;
}
.help-text, .helptext {
    display: block;
    padding: 7px 7px;
    margin-bottom: 14px;
    background: #393F3F;
    color: var(--color-lightGray);
    font-size: 10px;
    border-radius: 0 2px;
}
.content .helptext {
    background-color: #eee;
    color: #000;
}
input + .help-text {
    margin-top: -14px;
}
.formbox {
    min-height: 36px;
    line-height: 28px;
    margin-bottom: 14px;
}
.formbox.with-switch {
    padding-top: 2px;
}
.formbox select {
    width: calc(100% - 14px);
}
label {
    display: block;
    font-size: 12px;
    line-height: 21px;
    width: 100%;
}
.content label {
    font-weight: bold;
}
input[type="checkbox"] + label {
    display: inline;
    padding: 0 14px;
}
label input[type="radio"] {
    margin-right: 10px;
}
select + .error,
input + .error {
    display: block;
    padding: 7px 7px;
    margin-top: -14px;
    margin-bottom: 14px;
    background: var(--color-lightGray);
    color: #fff;
    background-color: #cc0000;
    font-size: 11px;
    border-radius: 0 2px;
}
input[type="file"] + .error {
    margin-top: 0;
}
input:invalid {
    border-color: red;
    background-color: darkred;
}
.dark input, .dark textarea {
    background-color: #232729;
    border-color: #1b1f20;
    color: #efefef;
}
.fieldset {
    margin-bottom: 5px;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
}
.dark .fieldset {
    border: 1px solid #222;
}
.fieldset .fields {
    visibility: hidden;
    opacity: 0;
    transition: visibility 0s, opacity 0.5s linear;
    height: 0;
    overflow: hidden;
}
.fieldset.toggle.on .fields {
    visibility: visible;
    opacity: 1;
    height: initial;
    padding: 10px;
}
.fieldset.toggle .legend {
    text-align: left;
    display: block;
    cursor: pointer;
    background-color: var(--color-lightGray);
    height: 30px;
    line-height: 30px;
    margin: 0;
    font-family: fira_sans;
    font-weight: normal;
    font-size: 1.2em;
    padding: 0 5px;
}
.dark .fieldset.toggle .legend {
    background-color: #232729;
    color: #fff;
}
.fieldset.toggle .legend:before {
    background-repeat: no-repeat;
    text-indent: 24px;
    height: 24px;
    width: 24px;
    line-height: 24px;
    display: inline-block;
    background-image: url('./img/16.svg');
    vertical-align: bottom;
    content: " ";
    background-position: -144px -76px;
}
.dark .fieldset.toggle .legend:before {
    background-image: url('./img/16-white.svg');
}
.fieldset.toggle.on .legend:before {
    background-position: -144px -51px;
}
fieldset legend {
    font-size: 1.1rem;
    padding: 0 5px;
}

/* Switch */
input.switch:empty {
    display: none;
}
input.switch:empty ~ label {
    white-space: nowrap;
    position: relative;
    float: left;
    line-height: 2em;
    height: 2em;
    text-indent: 6em;
    margin: 0.2em 0;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    text-shadow: 0 1px rgba(0, 0, 0, 0.1);
    width: 80px;
}
input.switch:empty ~ label:before,
input.switch:empty ~ label:after {
    position: absolute;
    display: block;
    top: 0;
    bottom: 0;
    left: 0;
    content: ' ';
    width: 6em;
    -webkit-transition: all 100ms ease-in;
    transition: all 100ms ease-in;
    color: #c9c9c7;
    font-weight: bold;
    background-color: #ededed;
}
.dark input.switch:empty ~ label:before,
.dark input.switch:empty ~ label:after {
    background-color: #272c2e;
}
input.switch:empty ~ label:after {
    width: 3em;
    margin-left: 0.1em;
    background-color: #ededed;
    content: "OFF";
    text-indent: 3.5em;
    border: 1px solid #374E75;
    font-weight: bold;
}
.dark input.switch:empty ~ label:after {
    border: 1px solid #202425;
    background-color: #2c3233;
}
input.switch:checked:empty ~ label:after {
    content: ' ';
}
.dark input.switch:checked ~ label:before,
input.switch:checked ~ label:before {
    background-color: #215d9c;
    content: "ON";
    text-indent: 0.7em;
    text-align: left;
    font-weight: bold;
}
input.switch:checked ~ label:after {
    margin-left: 3em;
}
.button-bar, .umap-multiplechoice {
    margin-top: 5px;
    text-align: center;
    display: grid;
    width: 100%
}
.button-bar {
    grid-gap: 7px;
}
.button-bar.half {
    grid-template-columns: 1fr 1fr;
}
.umap-multiplechoice.by3,
.umap-multiplechoice.by5 {
    grid-template-columns: 1fr 1fr 1fr;
}
.umap-multiplechoice.by4 {
    grid-template-columns: 1fr 1fr 1fr 1fr;
}
.button-bar .button,
.button-bar [type="button"] {
    display: inline-block;
}
.umap-multiplechoice input[type='radio'] {
    display: none;
}
.umap-multiplechoice label {
    border: 1px solid #374E75;
    cursor: pointer;
    background-color: #c9c9c7;
    min-height: 30px;
    line-height: 30px;
    text-align: center;
    width: 100%;
    display: inline-block;
}
.dark .umap-multiplechoice label {
    border: 1px solid black;
    background-color: #2c3233;
}
.umap-multiplechoice input[type='radio']:checked + label {
    background-color: #215d9c;
    box-shadow: inset 0 0 6px 0px #2c3233;
    color: #ededed;
}
.inheritable .header,
.inheritable {
    clear: both;
    overflow: hidden;
}
.inheritable .header {
    margin-bottom: 5px;
}
.inheritable .header label {
    padding-top: 6px;
}
.inheritable + .inheritable {
    border-top: 1px solid #222;
    padding-top: 5px;
    margin-top: 5px;
}
.umap-field-iconUrl .action-button,
.inheritable .define,
.inheritable .undefine {
    float: right;
    width: initial;
    min-height: 18px;
    line-height: 18px;
    margin-bottom: 0;
}
.inheritable .quick-actions {
    float: right;
}
.inheritable .quick-actions .formbox {
    margin-bottom: 0;
}
.inheritable .quick-actions input {
    width: 100px;
    margin-right: 5px;
}
.inheritable .define,
.inheritable.undefined .undefine,
.inheritable.undefined .show-on-defined {
    display: none;
}
.inheritable.undefined .define {
    display: block;
}
i.info {
    background-repeat: no-repeat;
    background-image: url('./img/16.svg');
    background-position: -170px -50px;
    display: inline-block;
    margin-left: 5px;
    vertical-align: middle;
    width: 16px;
    height: 18px;
}
.dark i.info {
    background-image: url('./img/16-white.svg');
}
.with-transition {
    transition: all .7s;
}

.umap-delete:before, .umap-empty:before, .umap-to-polygon:before,
.umap-clone:before, .umap-edit:before, .umap-download:before,
.umap-to-polyline:before {
    background-repeat: no-repeat;
    text-indent: 36px;
    height: 24px;
    line-height: 24px;
    display: inline-block;
    background-image: url('./img/24.svg');
    vertical-align: bottom;
    content: " ";
}
.dark .umap-delete:before, .dark .umap-empty:before,
.dark .umap-to-polygon:before,
.dark .umap-clone:before,
.dark .umap-edit:before, .dark .umap-download:before,
.dark .umap-to-polyline:before {
    background-image: url('./img/24-white.svg');
    vertical-align: middle;
}
.umap-to-polygon:before {
    background-position: -80px -48px;
}
.umap-to-polyline:before {
    background-position: -120px -48px;
}
.umap-clone:before {
    background-position: -150px -78px;
}
.umap-delete:before {
    background-position: -32px -8px;
}
.umap-edit:before {
    background-position: -6px -6px;
}
.umap-empty:before {
    background-position: -110px -78px;
}
.umap-download:before {
    background-position: -77px -78px;
}
.permissions-panel,
.umap-upload,
.umap-share,
.umap-datalayer-container,
.umap-layer-properties-container,
.umap-browse-data,
.umap-facet-search,
.umap-tilelayer-switcher-container {
    padding: 0 10px;
}
.umap-field-datalist {
    display: flex;
    justify-content: space-between;
    font-size: 9px;
    margin-top: -8px;
    padding: 0 5px;
}
.flat-tabs {
    display: flex;
    justify-content: space-around;
    font-size: 1.2em;
    margin-bottom: 20px;
    border-bottom: 1px solid #bebebe;
}
.flat-tabs button {
    padding: 10px;
    text-decoration: none;
    cursor: pointer;
    border-bottom: 1px solid transparent;
}
.flat-tabs button:hover,
.flat-tabs .on {
    font-weight: bold;
    border-bottom: 1px solid #444;
}
.dark .flat-tabs button {
    color: #fff;
}
.dark .flat-tabs button:hover,
.dark .flat-tabs .on {
    border-bottom: 1px solid #fff;
}
.umap-pictogram-category h6 {
    font-size: 1.3em;
}
.umap-pictogram-grid {
    display: grid;
    grid-template-columns: repeat(auto-fill, 30px);
    justify-content: space-between;
    grid-gap: 5px;
}
.umap-pictogram-choice {
    width: 30px;
    height: 30px;
    line-height: 30px;
    cursor: pointer;
    background-color: #999;
    text-align: center;
    margin-bottom: 5px;
    display: block;
    color: black;
    font-weight: bold;
}
.umap-pictogram-choice img {
    vertical-align: middle;
    max-width: 24px;
}
.umap-pictogram-choice:hover,
.umap-color-picker span:hover {
    background-color: #bebebe;
}
.umap-pictogram-choice.selected {
    box-shadow: inset 0 0 0 1px #e9e9e9;
}

.umap-pictogram-choice .leaflet-marker-icon {
    bottom: 0;
    left: 30px;
    position: absolute;
}
.umap-color-picker {
    clear: both;
    margin-bottom: 20px;
    overflow: hidden;
    display: none;
}
.umap-color-picker span {
    width: 20px;
    height: 20px;
    display: block;
    padding: 0;
    margin: 0;
    cursor: pointer;
    float: left;
}
input.blur {
    width: calc(100% - 40px);
    display: inline-block;
    vertical-align: middle;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.blur + .button:before,
.blur + [type="button"]:before {
    content: '✔';
}
.blur + .button,
.blur + [type="button"] {
    width: 40px;
    height: 18px;
    display: inline-block;
    vertical-align: middle;
    line-height: 18px;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    box-sizing: border-box;
}
input[type=hidden].blur + .button,
input[type=hidden].blur + [type="button"] {
    display: none;
}
.copiable-input {
    display: flex;
    align-items: end;
}
.copiable-input input {
    border-radius: initial;
}
.copiable-input button {
    background-repeat: no-repeat;
    background-image: url('./img/16.svg');
    background-position: -141px -140px;
    display: inline;
    padding: 0 10px;
    height: 32px;
    width: 32px;
    border: 1px solid #202425;
    border-radius: initial;
}

/* *********** */
/*    Panel    */
/* *********** */
.leaflet-ui-container {
    overflow-x: hidden;
}
.leaflet-top,
.leaflet-right {
    transition: all .7s;
}


/* *********** */
/*   Alerts    */
/* *********** */
#umap-alert-container {
    min-height: 46px;
    line-height: 46px;
    padding-left: 10px;
    width: calc(100% - 500px);
    position: absolute;
    top: -46px;
    left: 250px;  /* Keep save/cancel button accessible. */
    right: 250px;
    box-shadow: 0 1px 7px #999999;
    visibility: hidden;
    background: none repeat scroll 0 0 rgba(20, 22, 23, 0.8);
    font-weight: bold;
    color: #fff;
    font-size: 0.8em;
    z-index: 1012;
    border-radius: 2px;
}
#umap-alert-container.error {
    background-color: #c60f13;
}
.umap-alert #umap-alert-container {
    visibility: visible;
    top: 23px;
}
.umap-alert-container .umap-action {
    margin-left: 10px;
    background-color: #fff;
    color: #000;
    padding: 5px;
    border-radius: 4px;
}
.umap-alert-container .umap-action:hover {
    color: #000;
}
.umap-alert-container .error .umap-action {
    background-color: #666;
    color: #eee;
}
.umap-alert-container .error .umap-action:hover {
    color: #fff;
}
.umap-alert-container input {
    padding: 5px;
    border-radius: 4px;
    width: 100%;
}

/* *********** */
/*   Tooltip   */
/* *********** */
#umap-tooltip-container {
    line-height: 20px;
    padding: 5px 10px;
    width: auto;
    position: absolute;
    box-shadow: 0 1px 7px #999999;
    display: none;
    background-color: rgba(40, 40, 40, 0.8);
    color: #eeeeec;
    font-size: 0.8em;
    border-radius: 2px;
    z-index: 1011;
    font-weight: normal;
    max-width: 300px;
}
.umap-tooltip #umap-tooltip-container {
    display: block;
}
#umap-tooltip-container.tooltip-top:after {
    top: 100%;
    left: calc(50% - 11px);
    border: solid transparent;
    content: " ";
    height: 0;
    width: 0;
    position: absolute;
    pointer-events: none;
    border-top-color: rgba(30, 30, 30, 0.8);
    border-width: 11px;
    margin-left: calc(-50% + 21px);
}
#umap-tooltip-container.tooltip-bottom:before {
    top: -22px;
    left: calc(50% - 11px);
    border: solid transparent;
    content: " ";
    height: 0;
    width: 0;
    position: absolute;
    pointer-events: none;
    border-top-color: rgba(30, 30, 30, 0.7);
    border-width: 11px;
    transform: rotate(180deg);
}
#umap-tooltip-container.tooltip.tooltip-left:after {
    left: 100%;
    top: 50%;
    border: solid transparent;
    content: " ";
    height: 0;
    width: 0;
    position: absolute;
    pointer-events: none;
    border-color: rgba(136, 183, 213, 0);
    border-left-color: #333;
    border-width: 11px;
    margin-top: -10px;
}



/* *********** */
/* Close link  */
/* *********** */
#umap-alert-container .umap-close-link {
    color: #fff;
    float: right;
    padding-right: 10px;
    width: 100px;
    line-height: 1;
    margin: .5rem;
    background-color: #202425;
    font-size: .7rem;
}
#umap-alert-container .umap-close-icon {
    background-position: -74px -55px;
}
#umap-alert-container .umap-alert-actions {
    display: flex;
    margin: 1rem;
}
#umap-alert-container .umap-alert-actions .umap-action {
    margin-bottom: 0;
}


/* *********** */
/*   Various   */
/* *********** */

.umap-dragover:before {
    content:  ' ';
    background-image: url('data:image/svg+xml,%3Csvg xmlns="http://www.w3.org/2000/svg" width="200" height="200" viewBox="0 0 24 24" fill="none" stroke="white" stroke-width="2" stroke-linecap="round" stroke-linejoin="arcs">%3Cpath d="M3 15v4c0 1.1.9 2 2 2h14a2 2 0 0 0 2-2v-4M17 9l-5 5-5-5M12 12.8V2.5"/>%3C/svg>');
    background-repeat: no-repeat;
    background-position: center;
    background-color: #323e56;
    z-index: 401;
    display: block;
    position: absolute;
    width: 100vw;
    height: 100vh;
    opacity: 0.5;
}


/* *********** */
/*    Mobile   */
/* *********** */
@media all and (orientation:portrait) {
    #umap-alert-container {
        width: 100%;
        left: 0;
        right: 0;
    }
}
