const locale = {
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# one hash for main heading",
    "## two hashes for second heading": "## dos coixinets per a capçalera secundària",
    "### three hashes for third heading": "### three hashes for third heading",
    "**double star for bold**": "**doble asteric per a negreta**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 dia",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Quant a",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Afegeix una capa",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Add a new property",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "Opcions avançades",
    "Advanced properties": "Propietats avançades",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "S'han importat totes les propietats",
    "Allow interactions": "Allow interactions",
    "Allow scroll wheel zoom?": "Voleu permetre el zoom amb la roda de desplaçament?",
    "always": "always",
    "Animated transitions": "Transicions animades",
    "Are you sure you want to cancel your changes?": "Esteu segur de voler cancel·lar els canvis?",
    "Are you sure you want to clone this map and all its datalayers?": "Esteu segur de voler clonar aquest mapa i totes les capes de dades?",
    "Are you sure you want to delete the feature?": "Segur que voleu suprimir la característica?",
    "Are you sure you want to delete this layer?": "Are you sure you want to delete this layer?",
    "Are you sure you want to delete this map?": "Esteu segur de voler suprimir aquest mapa?",
    "Are you sure you want to delete this property on all the features?": "Are you sure you want to delete this property on all the features?",
    "Are you sure you want to restore this version?": "Are you sure you want to restore this version?",
    "Attach the map to my account": "Adjunta el mapa al meu compte",
    "attribution": "atribució",
    "Auto": "Auto",
    "Automatic": "Automatic",
    "Autostart when map is loaded": "Autostart when map is loaded",
    "Back to preview": "Back to preview",
    "Background overlay url": "URL de superposició del fons",
    "Ball": "Bola",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Explora les dades",
    "by": "per",
    "Cache proxied request": "Petició proxy en memòria cau",
    "Cancel edits": "Cancel·la les edicions",
    "Cancel": "Cancel·la",
    "Caption": "Llegenda",
    "Center map on your location": "Centra el mapa a la vostra ubicació",
    "Change map background": "Canvia el fons del mapa",
    "Change tilelayers": "Canvia les capes de tessel·les",
    "Change": "Change",
    "Choose a preset": "Choose a preset",
    "Choose the data format": "Trieu el format de dades",
    "Choose the format of the data to import": "Trieu el format de les dades a importar",
    "Choose the layer to import in": "Trieu la capa que on voleu importar",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Cercle",
    "clear": "clear",
    "Click last point to finish shape": "Click last point to finish shape",
    "Click to add a marker": "Feu clic per a afegir una marca",
    "Click to continue drawing": "Click to continue drawing",
    "Click to edit": "Click to edit",
    "Click to start drawing a line": "Click to start drawing a line",
    "Click to start drawing a polygon": "Click to start drawing a polygon",
    "Clone of {name}": "Clona de {name}",
    "Clone this feature": "Clone this feature",
    "Clone this map": "Clona aquest mapa",
    "Clone": "Clona",
    "Close": "Tanca",
    "Clustered": "Clustered",
    "Clustering radius": "Clustering radius",
    "collapsed": "collapsed",
    "color": "color",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Llista separada per comes de les propietats a usar per a les característiques d'ordenació. Per a invertir l'ordre, afegiu un signe menys (-) abans. P. ex. lamevaclau, -unaslatraclau",
    "Comma separated list of properties to use when filtering features": "Comma separated list of properties to use when filtering features",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Enhorabona, s'ha creat el mapa!",
    "Continue line": "Continue line",
    "Coordinates": "Coordenades",
    "Copy link": "Copia l'enllaç",
    "copy": "copy",
    "Credits": "Crèdits",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Voleu la visualització actual en comptes de la visualització predeterminada?",
    "Custom background": "Fons personalitzat",
    "Custom overlay": "Superposició personalitzada",
    "dash array": "dash array",
    "Data browser": "Data browser",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Datalayers",
    "Default interaction options": "Default interaction options",
    "Default properties": "Propietats predeterminades",
    "Default shape properties": "Default shape properties",
    "Default view": "Default view",
    "Default zoom level": "Default zoom level",
    "Default": "Per defecte",
    "Default: name": "Default: name",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "define",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete all layers": "Delete all layers",
    "Delete layer": "Delete layer",
    "Delete this feature": "Suprimeix aquesta característica",
    "Delete this property on all the features": "Suprimeix aquesta propietat a totes les característiques",
    "Delete this shape": "Delete this shape",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Delete": "Suprimeix",
    "description": "descripció",
    "Direct link": "Enllaç directe",
    "Directions from here": "Direccions des d'aquí",
    "Display label": "Display label",
    "Display measure": "Display measure",
    "display name": "mostra el nom",
    "Display on load": "Mostrar en carregar",
    "Display the control to open OpenStreetMap editor": "Display the control to open OpenStreetMap editor",
    "Display the data layers control": "Display the data layers control",
    "Display the embed control": "Display the embed control",
    "Display the fullscreen control": "Display the fullscreen control",
    "Display the locate control": "Display the locate control",
    "Display the measure control": "Display the measure control",
    "Display the search control": "Display the search control",
    "Display the star map button": "Mostra el botó per a destacar el mapa",
    "Display the tile layers control": "Display the tile layers control",
    "Display the zoom control": "Display the zoom control",
    "Do you want to display a caption bar?": "Voleu mostrar la barra de llegenda?",
    "Do you want to display a minimap?": "Voleu mostrar un minimapa?",
    "Do you want to display a panel on load?": "Voleu mostrar el quandre en carregar?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Voleu mostrar un peu emergent?",
    "Do you want to display the scale control?": "Voleu mostrar el control d'escala?",
    "Do you want to display the «more» control?": "Do you want to display the «more» control?",
    "Download": "Baixa",
    "Drag to reorder": "Drag to reorder",
    "Draw a marker": "Dibuixa un marcador",
    "Draw a polygon": "Dibuixa un polígon",
    "Draw a polyline": "Dibuixa una polilínia",
    "Drawing": "Drawing",
    "Drop": "Deixar",
    "Dynamic properties": "Dynamic properties",
    "Dynamic": "Dinàmic",
    "Edit feature's layer": "Edita la capa de la característica",
    "Edit properties in a table": "Edita les propietats en una taula",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Edita aquesta característica",
    "Edit": "Edita",
    "Email": "Envia per correu electrònic",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Incrusta el mapa",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Buit",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "S'ha produït un error en l'URL de superposició",
    "Error in the tilelayer URL": "Hi ha un error en l'URL de la cap de tessel·les",
    "Exit Fullscreen": "Exit Fullscreen",
    "expanded": "expanded",
    "Extract shape to separate feature": "Extract shape to separate feature",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "emplena el color",
    "fill opacity": "opacitat d'emplenament",
    "fill": "emplena",
    "Filter keys": "Filter keys",
    "Filter": "Filter",
    "Fit all data": "Fit all data",
    "Format": "Format",
    "From zoom": "Del zoom",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (només enllaç)",
    "GeoRSS (title + image)": "GeoRSS (títol i imatge)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Vés a «{feature}»",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Heatmap radius",
    "Heatmap": "Heatmap",
    "height": "alçada",
    "Help": "Ajuda",
    "hidden": "hidden",
    "Hide controls": "Amaga els controls",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "icon opacity": "opacitat de la icona",
    "Icon shape": "Icon shape",
    "Icon symbol": "Icon symbol",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imatge amb amplada personalitzada (en px): {{http://imatge.url.com|amplada}}",
    "Image: {{http://image.url.com}}": "Imatge: {{http://imatge.url.com}}",
    "Import data": "Importa dades",
    "Import in a new layer": "Import in a new layer",
    "Import": "Importa",
    "Imports all umap data, including layers and settings.": "Imports all umap data, including layers and settings.",
    "Include full screen link?": "Voleu incloure l'enllaç a pantalla completa?",
    "Inherit": "Hereta",
    "inherit": "heretat",
    "Interaction options": "Interaction options",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Invalid umap data in {filename}",
    "Invalid umap data": "Invalid umap data",
    "Invalide property name: {name}": "Invalide property name: {name}",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Keep current visible layers",
    "kilometers": "quilòmetres",
    "km": "km",
    "Label direction": "Label direction",
    "Label key": "Label key",
    "Labels are clickable": "Labels are clickable",
    "Latest feature": "Latest feature",
    "Latitude": "Latitud",
    "Layer properties": "Layer properties",
    "Layer": "Capa",
    "Licence": "Llicència",
    "licence": "llicència",
    "Limit bounds": "Límits",
    "Link to view the map": "Link to view the map",
    "Link to…": "Link to…",
    "Link with text: [[http://example.com|text of the link]]": "Enllaceu amb el text:  [[http://exemple.com|text de l'enllaç]]",
    "Long credits": "Long credits",
    "Longitude": "Longitud",
    "Make main shape": "Make main shape",
    "Manage layers": "Manage layers",
    "Manual": "Manual",
    "Map background credits": "Crèdits del fons del mapa",
    "Map has been attached to your account": "El mapa s'ha adjuntat al vostre compte",
    "Map has been saved!": "S'ha desat el mapa!",
    "Map has been starred": "El mapa s'ha destacat",
    "Map has been unstarred": "El mapa ja no està destacat",
    "Map user content has been published under licence": "El contingut de l'usuari del mapa s'ha publicat sota la llicència",
    "Map's editors": "Editors del mapa",
    "Map's owner": "Propietari del mapa",
    "max East": "Est màxim",
    "max North": "Nord màxim",
    "max South": "Sud màxim",
    "max West": "Oest màxim",
    "max zoom": "escala màxima",
    "Measure distances": "Mesura distàncies",
    "Merge lines": "Merge lines",
    "mi": "mi",
    "miles": "milles",
    "min zoom": "escala mínima",
    "More controls": "Més controls",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Must be a valid CSS value (eg.: DarkBlue or #123456)",
    "name": "nom",
    "nautical miles": "miles nàutiques",
    "never": "never",
    "new window": "new window",
    "next": "next",
    "NM": "NM",
    "No cache": "Sense memòria cau",
    "No licence has been set": "No licence has been set",
    "No results for these facets": "No results for these facets",
    "No results": "No results",
    "no": "no",
    "No.": "No.",
    "None": "Cap",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "On the bottom",
    "On the left": "On the left",
    "On the right": "On the right",
    "On the top": "On the top",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "opacitat",
    "Opacity": "Opacitat",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Open link in…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Opcional. El mateix color si no s'estableix.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "parent window": "parent window",
    "Paste your data here": "Enganxeu les dades aquí",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Assegureu-vos que la llicència és compatible amb l'ús que en feu.",
    "Please choose a format": "Please choose a format",
    "Please enter the name of the property": "Introduïu el nom de la propietat",
    "Please enter the new name of this property": "Introduïu el nom d'aquesta propietat",
    "Please save the map first": "Abans deseu el mapa",
    "Popup (large)": "Finestra emergent (gran)",
    "Popup content style": "Estil del contingut de la finestra emergent",
    "Popup content template": "Popup content template",
    "Popup shape": "Forma de la finestra emergent",
    "Popup": "Finestra emergent",
    "Powered by uMap": "Powered by uMap",
    "previous": "previous",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Propietats importades:",
    "Provide an URL here": "Proporcioneu un URL aquí",
    "Proxy request": "Petició proxy",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Dades remotes",
    "Remove shape from the multi": "Remove shape from the multi",
    "Rename this property on all the features": "Canvia el nom d'aquesta propietat en totes les característiques",
    "Replace layer content": "Replace layer content",
    "Restore this version": "Restore this version",
    "Save anyway": "Desa-ho igualment",
    "Save current edits": "Desa les edicions actuals",
    "Save map": "Save map",
    "Save this center and zoom": "Desa aquest centre i escala",
    "Save this location as new feature": "Save this location as new feature",
    "Save": "Desa",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Search location",
    "Search": "Search",
    "Secret edit link copied to clipboard!": "L'enllaç secret s'ha copiat al porta-retalls!",
    "Secret edit link:": "Secret edit link:",
    "See layers": "See layers",
    "See full screen": "Mostra-ho a pantalla completa",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Select data": "Select data",
    "Send me the link": "Envia'm aquest enllaç",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Shape properties",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Short credits",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Mostra/amaga la capa",
    "Side panel": "Side panel",
    "Simple link: [[http://example.com]]": "Enllaç simple: [[http://exemple.com]]",
    "Simplify": "Simplify",
    "Skipping unknown geometry.type: {type}": "S'està ometent el tipus de geometria desconegut: {type}",
    "Slideshow": "Presentació",
    "Sort key": "Sort key",
    "Split line": "Split line",
    "Star this map": "Destaca aquest mapa",
    "Start a hole here": "Start a hole here",
    "Start slideshow": "Inicia la presentació",
    "Stop editing": "Atura l'edició",
    "Stop slideshow": "Atura la presentació",
    "Street": "Street",
    "stroke": "stroke",
    "Supported scheme": "Esquema suportat",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol": "Symbol",
    "Table": "Taula",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Format del text",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "L'escala i el centre s'han modificat.",
    "TMS format": "Format TMS",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "A l'escala",
    "Toggle edit mode (⇧+Click)": "Activa o desactiva el mode d'edició (⇧+clic)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Transforma a línies",
    "Transform to polygon": "Transforma a polígon",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tipus de capa",
    "Unable to detect format of file {filename}": "Unable to detect format of file {filename}",
    "Untitled layer": "Capa sense títol",
    "Untitled map": "Mapa sense títol",
    "Update permissions and editors": "Actualitza els permisos i editors",
    "Update permissions": "Actualitza els permisos",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Usa els límits actuals",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Crèdits dels continguts de l'usuari",
    "User interface options": "Opcions de la interfície d'usuari",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versions",
    "View Fullscreen": "View Fullscreen",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "pes",
    "Where do we go from here?": "On anem des d'aquí?",
    "Whether to display or not polygons paths.": "Whether to display or not polygons paths.",
    "Whether to fill polygons with color.": "Whether to fill polygons with color.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Qui pot editar",
    "Who can view": "Qui pot visualitzar",
    "width": "amplada",
    "Will be displayed in the bottom right corner of the map": "Will be displayed in the bottom right corner of the map",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Will be visible in the caption of the map",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.",
    "yes": "sí",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "S'ha creat el vostre mapa! Com que no heu iniciat sessió, aquí teniu l'enllaç secret per a editar-lo. Conserveu-lo en un lloc segur:",
    "Zoom in": "Apropa't",
    "Zoom level for automatic zooms": "Zoom level for automatic zooms",
    "Zoom out": "Allunya't",
    "Zoom to layer extent": "Zoom to layer extent",
    "Zoom to the next": "Zoom to the next",
    "Zoom to the previous": "Zoom to the previous",
    "Zoom to this feature": "Fes zoom a aquesta característica",
    "Zoom to this place": "Zoom to this place",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{delay} seconds",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} milles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Layers": "Layers",
    "Display the caption control": "Display the caption control",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Data": "Data",
    "Filters": "Filters"
}
L.registerLocale("ca", locale)
L.setLocale("ca")
